==> mozilla-source-1.4.tar.bz2: mozilla/extensions/transformiix/source/xslt/txXSLTProcessor.cpp <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TransforMiiX XSLT processor.
 *
 * The Initial Developer of the Original Code is
 * Jonas Sicking.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * Jonas Sicking. All Rights Reserved.
 *
 * Contributor(s):
 *   Jonas Sicking <jonas@sicking.cc>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "txXSLTProcessor.h"
#include "txInstructions.h"
#include "txAtoms.h"
#include "TxLog.h"
#include "txStylesheetCompileHandlers.h"
#include "txExecutionState.h"
#ifdef TX_EXE
#include "txHTMLOutput.h"
#endif

TX_LG_IMPL;

/* static */
MBool
txXSLTProcessor::init()
{
    TX_LG_CREATE;

#ifdef TX_EXE
    if (!txNamespaceManager::init())
        return MB_FALSE;

    if (NS_FAILED(txHTMLOutput::init())) {
        return MB_FALSE;
    }
#endif

    if (!txHTMLAtoms::init())
        return MB_FALSE;
    if (!txXMLAtoms::init())
        return MB_FALSE;
    if (!txXPathAtoms::init())
        return MB_FALSE;
    if (!txXSLTAtoms::init())
        return MB_FALSE;
    
    if (!txHandlerTable::init())
        return MB_FALSE;

    return MB_TRUE;
}

/* static */
void
txXSLTProcessor::shutdown()
{
#ifdef TX_EXE
    txNamespaceManager::shutdown();
    txHTMLOutput::shutdown();
#endif

    txHTMLAtoms::shutdown();
    txXMLAtoms::shutdown();
    txXPathAtoms::shutdown();
    txXSLTAtoms::shutdown();

    txHandlerTable::shutdown();

    TX_LG_DELETE;
}


/* static */
nsresult
txXSLTProcessor::execute(txExecutionState& aEs)
{
    nsresult rv = NS_OK;
    txInstruction* instr;
    while ((instr = aEs.getNextInstruction())) {
        rv = instr->execute(aEs);
        NS_ENSURE_SUCCESS(rv, rv);
    }

    return NS_OK;
}

==> mozilla-source-1.7.tar.bz2: mozilla/extensions/transformiix/source/xslt/txXSLTProcessor.cpp <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TransforMiiX XSLT processor.
 *
 * The Initial Developer of the Original Code is
 * Jonas Sicking.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * Jonas Sicking. All Rights Reserved.
 *
 * Contributor(s):
 *   Jonas Sicking <jonas@sicking.cc>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "txXSLTProcessor.h"
#include "txInstructions.h"
#include "txAtoms.h"
#include "TxLog.h"
#include "txStylesheetCompileHandlers.h"
#include "txExecutionState.h"
#include "ExprResult.h"
#ifdef TX_EXE
#include "txHTMLOutput.h"
#endif

TX_LG_IMPL

/* static */
MBool
txXSLTProcessor::init()
{
    TX_LG_CREATE;

#ifdef TX_EXE
    if (!txNamespaceManager::init())
        return MB_FALSE;

    if (NS_FAILED(txHTMLOutput::init())) {
        return MB_FALSE;
    }
#endif

    txXMLAtoms::init();
    txXPathAtoms::init();
    txXSLTAtoms::init();
    txHTMLAtoms::init();
    
    if (!txHandlerTable::init())
        return MB_FALSE;

    return MB_TRUE;
}

/* static */
void
txXSLTProcessor::shutdown()
{
#ifdef TX_EXE
    txNamespaceManager::shutdown();
    txHTMLOutput::shutdown();
#endif

    txHandlerTable::shutdown();
}


/* static */
nsresult
txXSLTProcessor::execute(txExecutionState& aEs)
{
    nsresult rv = NS_OK;
    txInstruction* instr;
    while ((instr = aEs.getNextInstruction())) {
        rv = instr->execute(aEs);
        NS_ENSURE_SUCCESS(rv, rv);
    }

    return NS_OK;
}
